@@ -1,4 +1,5 @@
 import json
+from os import path
 import pytz
 from enum import Enum
 from inspect import Parameter, signature
@@ -6,8 +7,9 @@ from pydantic import Field, root_validator, validator
 from typing import Any, Dict, List, Optional, Union
 from fhir.resources.fhirtypesvalidators import MODEL_CLASSES
 
+from linuxforhealth.csvtofhir.config import get_converter_config
 from linuxforhealth.csvtofhir.model.base import ImmutableModel
-from linuxforhealth.csvtofhir.support import get_logger
+from linuxforhealth.csvtofhir.support import get_logger, parse_uri_scheme, open_file
 
 logger = get_logger(__name__)
 
@@ -63,6 +65,10 @@ class GeneralSection(ImmutableModel):
         default=DataStreamType.LIVE
     )
     emptyFieldValues: Optional[List[str]]
+    regexFilenames: bool = Field(
+        description="Controls whether the filenames should be compared using regex or simple string comparision",
+        default = False
+    )
 
     @validator("timeZone")
     def validate_time_zone(cls, v):
@@ -121,6 +127,13 @@ class FileDefinition(ImmutableModel):
                     "Required field when fileType = fixed width"
     )
 
+    skiprows: Optional[Union[int, List[int]]] = Field(
+        description="Skip rows from the csv file. Value can be in integet to skip that many lines from the " +
+                    "top, or an array to skip rows with that index (0 based). e.g. `[2, 3]` will skip row 3" +
+                    "and 4 from the file (including headers)",
+        default=None
+    )
+
     tasks: Optional[List[Task]] = Field(
         description="Tasks are used to transform CSV source records to the internal record format."
     )
@@ -201,7 +214,6 @@ class FileDefinition(ImmutableModel):
         return values
 
 
-
 class DataContract(ImmutableModel):
     """
     Specifies how CSV records are mapped to FHIR resources.
@@ -209,10 +221,29 @@ class DataContract(ImmutableModel):
     general: GeneralSection = Field(
         description="Contains settings applicable to all files"
     )
-    fileDefinitions: Dict[str, FileDefinition] = Field(
+    fileDefinitions: Dict[str, Union[FileDefinition, str] ] = Field(
         description="The DataContract's CSVToFHIR resource mappings"
     )
 
+    @validator("fileDefinitions")
+    def load_file_definitions(cls, values):
+        try:
+            for key, value in values.items():
+                if isinstance(value, str):
+                    if parse_uri_scheme(value) == 'file' and not path.isabs(value):
+                        file_directory = path.dirname(get_converter_config().configuration_path)
+                        filepath = path.join(file_directory, value)
+                    else:
+                        filepath = value
+
+                    with open_file(filepath) as fd:
+                        file_definition = FileDefinition(**json.load(fd))
+                        values[key] = file_definition
+            return values
+        except Exception as e:
+            logger.error(f"Error fetching linked file definition {value}", exc_info=e)
+            raise e
+        
 
 def load_data_contract(file_path: str) -> DataContract:
     """
@@ -220,5 +251,5 @@ def load_data_contract(file_path: str) -> DataContract:
     :param file_path: The path to the resource mapping configuration
     :return: dictionary
     """
-    with open(file_path, "rt") as r:
+    with open_file(file_path, "rt") as r:
         return DataContract(**json.load(r))
