@@ -2,8 +2,15 @@ import csv
 import json
 import logging
 import os
-from logging import NullHandler
 from typing import Dict, List
+from urllib.parse import urlparse
+import re
+
+# regex to see if a path is a windows path, beginning with a "drive" letter
+is_windows_path = re.compile("^[a-zA-Z]:")
+
+# open function from the base library
+_base_library_open = open
 
 
 def find_fhir_resources(resources: List, resource_type: str) -> List[Dict]:
@@ -22,6 +29,20 @@ def find_fhir_resources(resources: List, resource_type: str) -> List[Dict]:
     return matches
 
 
+def get_fhir_resource_types(resources: List) -> List[str]:
+    """
+    Returns resource types from a list
+    :param resources: List of resources
+    :return: List of resource types
+    """
+    retVal = []
+    for result in resources:
+        resource = json.loads(result)
+        retVal.append(resource.get("resourceType", ""))
+
+    return retVal
+
+
 def read_csv(filepath: str) -> Dict:
     """
     Reads a csv file and converts to Dict
@@ -48,13 +69,14 @@ def get_logger(name):
     :return: Returns the logger object
     """
     logger = logging.getLogger(name)
-    logger.addHandler(NullHandler())
+    logger.addHandler(logging.NullHandler())
+    logger.setLevel(logging.INFO)
 
     # uncomment the lines below to enable local environment logging
 
     # from logging import StreamHandler
     # logger.setLevel(logging.DEBUG)
-    # stream_handler = StreamHandler()
+    # stream_handler = logging.StreamHandler()
     # stream_handler.setLevel(logging.DEBUG)
     #
     # formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
@@ -93,3 +115,29 @@ def validate_paths(paths: List[str], raise_exception=True) -> List[str]:
         raise FileNotFoundError(msg)
 
     return invalid_paths
+
+
+def parse_uri_scheme(uri: str) -> str:
+    """
+    Parses the scheme from a URI.
+    Delegates to smart_open.parse_uri() URIs object if available.
+    If not smart_open is not available, urlparse is used.
+    """
+    # windows path, assume a "file" scheme
+    if is_windows_path.match(uri):
+        return "file"
+    try:
+        from smart_open import parse_uri
+        return parse_uri(uri).scheme
+    except ImportError:
+        # parse the uri using "file" as a default scheme
+        return urlparse(uri, scheme="file")[0]
+
+
+def open_file(*args, **kwargs):
+    """Opens a file based on installed options."""
+    try:
+        from smart_open import open
+        return open(*args, **kwargs)
+    except ImportError:
+        return _base_library_open(*args, **kwargs)
